@@ -12,7 +12,7 @@ from typing import Any, Dict, List
 from . import debug_helper, token_utils, utils
 from .ft_gettext import current_lang
 from .path_info import path_utils
-from .typing import ObjectsInfo, ScopeKind, SimilarNamesInfo
+from .typing_info import ObjectsInfo, ScopeKind, SimilarNamesInfo
 
 # third-party
 try:
