@@ -6,6 +6,7 @@ modules_attributes.py located in this directory.
 """
 import sys
 from pprint import pprint
+
 from stdlib_modules import names
 
 all_attributes = {}
@@ -35,5 +36,5 @@ for mod_name in names:
 
 
 print(f"# Created with {sys.version_info}")
-print("attribute_names = ", end='')
+print("attribute_names = ", end="")
 pprint(all_attributes)
